@@ -22,8 +22,8 @@
 
 """
 `loggingpython` is a Python package that provides a simple and extensible way
- to integrate logging into your applications. The package starts with a basic
- logger and can be extended with additional functions to meet the requirements
+to integrate logging into your applications. The package starts with a basic
+logger and can be extended with additional functions to meet the requirements
 of your application.
 
 This module contains various handler classes that can be used for different
@@ -32,12 +32,12 @@ logging.
 
 Examples:
     >>> from loggingpython.handler import FileHandler
-    >>> file_handler = FileHandler('logfile.log')
-    >>> file_handler.log('This is a log message.')
+    >>> file_handler = FileHandler('myLogger')
+    >>> file_handler.emit('This is a log message.')
 
     >>> from loggingpython.handler import ConsoleHandler
     >>> console_handler = ConsoleHandler()
-    >>> console_handler.log('This is a log message.')
+    >>> console_handler.emit('This is a log message.')
 
 In the Docs you will find further information about.
 """
@@ -64,7 +64,7 @@ from .error.invalid_handler_method_error import InvalidHandlerMethodError
 from .error.handler_not_found_error import HandlerNotFoundError
 
 
-__version__ = "1.4.1"
+__version__ = "1.4.13"
 __all__ = [
     # Bacis
     "Logger",
