@@ -1,17 +1,17 @@
 # MIT License
-
+#
 # Copyright (c) 2024 Mr-Major-K
-
+#
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
 # in the Software without restriction, including without limitation the rights
 # to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 # copies of the Software, and to permit persons to whom the Software is
 # furnished to do so, subject to the following conditions:
-
+#
 # The above copyright notice and this permission notice shall be included in
 # all copies or substantial portions of the Software.
-
+#
 # THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 # IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 # FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
@@ -21,6 +21,8 @@
 # SOFTWARE.
 
 """
+`loggingpython`
+
 A class for handling log messages in a structured and extensible way.
 
 This class, `Logger`, is designed to provide a simple and customizable
@@ -59,6 +61,8 @@ from .error.handler_not_found_error import HandlerNotFoundError
 
 class Logger:
     """
+    `loggingpython`
+
     A class for handling log messages in a structured and extensible way.
 
     This class, `Logger`, is designed to provide a simple and customizable
